# This file is part of trytond_backend_gis.  The COPYRIGHT file at the top
# level of this repository contains the full copyright notices and license
# terms.
from trytond.model import fields


class Geometry(fields.Field):
    _type = 'geometry'
    _geometry_type = 'GEOMETRY'

    def __init__(self, string='', srid=4326, dimension=2, loading='lazy',
            **kwargs):
        super(Geometry, self).__init__(
            string=string, loading=loading, **kwargs)
        self.srid = srid
        self.dimension = dimension

    @property
    def _sql_type(self):
        return 'GIS_%s(%s, %s)' % (
            self._geometry_type, self.srid, self.dimension)


class Point(Geometry):
    _geometry_type = 'POINT'


class LineString(Geometry):
    _geometry_type = 'LINESTRING'


class Polygon(Geometry):
    _geometry_type = 'POLYGON'


class MultiPoint(Geometry):
    _geometry_type = 'MULTIPOINT'


class MultiLineString(Geometry):
    _geometry_type = 'MULTILINESTRING'


class MultiPolygon(Geometry):
    _geometry_type = 'MULTIPOLYGON'


class GeometryCollection(Geometry):
    _geometry_type = 'GEOMETRYCOLLECTION'
