# This file is part of trytond_backend_gis.  The COPYRIGHT file at the top
# level of this repository contains the full copyright notices and license
# terms.
import re

from trytond.transaction import Transaction
from trytond.backend.postgresql.table import TableHandler as PGTableHandler

__all__ = ['TableHandler']

GIS_RE = re.compile(
    r'GIS_(?P<type>[A-Z]+)\((?P<srid>[0-9]+), (?P<dimension>[0-9]+)\)')


class TableHandler(PGTableHandler):

    def add_column(self, column_name, abstract_type, default=None, comment=''):
        if abstract_type.startswith('GIS_'):
            column_adder = self.add_geometry_column
        else:
            column_adder = super(TableHandler, self).add_column
        column_adder(column_name, abstract_type, default, comment)

    def add_geometry_column(self, column_name, abstract_type, default_fun=None,
            fill_default=True, comment=''):
        cursor = Transaction().connection.cursor()

        if self.column_exist(column_name):
            # TODO check for type and eventual migration
            return

        match = GIS_RE.match(abstract_type)
        assert match is not None, \
            'The abstract type %s is not supported' % abstract_type
        type_ = match.group('type')
        srid, dimension = map(int, match.group('srid', 'dimension'))
        cursor.execute('SELECT AddGeometryColumn(%s, %s, %s, %s, %s)',
            (self.table_name, column_name, srid, type_, dimension))
        self._update_definitions(columns=True)
