# This file is part of trytond_backend_gis.  The COPYRIGHT file at the top
# level of this repository contains the full copyright notices and license
# terms.
import os
import unittest

from dbgis import Point

from trytond import backend
from trytond.pool import Pool
from trytond.transaction import Transaction
from trytond.tests.test_tryton import (create_db, activate_module,
    with_transaction)


def setUpModule():
    import pkg_resources
    from trytond.modules import MODULES, EGG_MODULES
    from trytond_backend_gis.tests.test_gis import register

    # This is necessary because EGG_MODULES populates the module list returned
    # by get_module_list
    entry_points = pkg_resources.iter_entry_points('trytond.test_modules')
    for test_entry_point in entry_points:
        if test_entry_point.name == 'test_gis':
            EGG_MODULES['test_gis'] = test_entry_point
            break

    register()
    MODULES.append('test_gis')


class TestGeographicFields:

    @classmethod
    def setUpClass(cls):
        activate_module('test_gis')

    @with_transaction()
    def test_point(self):
        pool = Pool()

        GISPoint = pool.get('gis.point')
        point1, = GISPoint.create([{
                    'point': Point(1, 2, srid=4326),
                    }])
        self.assert_(point1)
        self.assertEqual(point1.point.x, 1)
        self.assertEqual(point1.point.y, 2)
        self.assertEqual(point1.point.srid, 4326)


@unittest.skipUnless(backend.name() == 'postgis', "requires PostGIS")
class PostGISTestCase(TestGeographicFields, unittest.TestCase):
    "Test PostGIS Geographic Fields"

    @classmethod
    def setUpClass(cls):
        DB_NAME = os.environ['DB_NAME']
        create_db(DB_NAME)
        with Transaction().start(DB_NAME, 1) as transaction:
            cursor = transaction.connection.cursor()
            cursor.execute("CREATE EXTENSION postgis")
        super(PostGISTestCase, cls).setUpClass()


def suite():
    suite_ = unittest.TestSuite()
    suite_.addTests(unittest.TestLoader().loadTestsFromTestCase(
            PostGISTestCase))
    return suite_
